@@ -1,11 +1,11 @@
 import os
-from english_heroku import heroku_words
+from .english_heroku import heroku_words
 
 class Anagram(object):
     
     __author__ = 'Michael S. Russell'
     __email__ = 'michael.r2014@yahoo.co.uk'
-    __version__ = '1.0.9'
+    __version__ = '1.0.12'
     
     def __init__(self):
         
@@ -27,7 +27,7 @@ class Anagram(object):
             with open(self.path + "\\english.txt", "r") as r:
                 words = r.read().replace("\n", ",").split(",")
 
-        self.words = words
+            self.words = words
         
     
     def enter_words_print(self):
